@@ -48,6 +48,7 @@
 #define HAVE_TIME_H 1
 #define HAVE_UTIME_H 1
 #define HAVE_GMP_H 1
+#define HAVE_LIBGMP 1
 #define HAVE_TYPEOF 1
 #define HAVE_LONG_LONG 1
 #define HAVE_OFF_T 1
@@ -120,7 +121,8 @@
 #define PUREFUNC(x) __attribute__ ((__pure__)) x
 #define NORETURN(x) __attribute__ ((__noreturn__)) x
 #define DEPRECATED(x) __attribute__ ((__deprecated__)) x
-#define DEPRECATED_TYPE(mesg,x) __attribute__ ((__deprecated__ mesg)) x
+#define DEPRECATED_BY(n,x) __attribute__ ((__deprecated__("by "#n))) x
+#define DEPRECATED_TYPE(mesg,x) x __attribute__ ((__deprecated__ mesg))
 #define NOINLINE(x) __attribute__ ((__noinline__)) x
 #define ALWAYS_INLINE(x) __attribute__ ((__always_inline__)) x
 #define WARN_UNUSED_RESULT(x) __attribute__ ((__warn_unused_result__)) x
@@ -130,6 +132,8 @@
 #define HAVE_ATTRIBUTE_FUNCTION_ALIAS 1
 #define RUBY_ALIAS_FUNCTION_TYPE(type, prot, name, args) type prot __attribute__((alias(#name)));
 #define RUBY_ALIAS_FUNCTION_VOID(prot, name, args) RUBY_ALIAS_FUNCTION_TYPE(void, prot, name, args)
+#define HAVE_GCC_ATOMIC_BUILTINS 1
+#define HAVE_GCC_SYNC_BUILTINS 1
 #define RUBY_FUNC_EXPORTED __attribute__ ((__visibility__("default"))) extern
 #define ENUM_OVER_INT 1
 #define HAVE_DECL_SYS_NERR 1
@@ -309,6 +313,9 @@
 #define HAVE_UTIMES 1
 #define HAVE_WAIT4 1
 #define HAVE_WAITPID 1
+#define HAVE_BUILTIN___BUILTIN_BSWAP16 1
+#define HAVE_BUILTIN___BUILTIN_BSWAP32 1
+#define HAVE_BUILTIN___BUILTIN_BSWAP64 1
 #define HAVE_BUILTIN___BUILTIN_POPCOUNT 1
 #define HAVE_BUILTIN___BUILTIN_POPCOUNTLL 1
 #define HAVE_BUILTIN___BUILTIN_CLZ 1
@@ -318,6 +325,7 @@
 #define HAVE_BUILTIN___BUILTIN_CTZLL 1
 #define HAVE_BUILTIN___BUILTIN_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR 1
+#define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_TYPES_COMPATIBLE_P 1
 #define ATAN2_INF_C99 1
 #define HAVE_CLOCK_GETRES 1
@@ -354,6 +362,7 @@
 #define UCONTEXT_IN_SIGNAL_H 1
 #define DEFINE_MCONTEXT_PTR(mc, uc) mcontext_t *mc = &(uc)->uc_mcontext
 #define USE_ELF 1
+#define HAVE_ELF_H 1
 #define HAVE_ELF_ABI_H 1
 #define DLEXT_MAXLEN 3
 #define DLEXT ".so"
