@@ -10,7 +10,7 @@
 
 module RbConfig
   RUBY_VERSION.start_with?("2.4.") or
-    raise "ruby lib version (2.4.2) doesn't match executable version (#{RUBY_VERSION})"
+    raise "ruby lib version (2.4.3) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.4/arm-openbsd")
@@ -21,9 +21,9 @@ module RbConfig
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "2"
   CONFIG["MINOR"] = "4"
-  CONFIG["TEENY"] = "2"
-  CONFIG["PATCHLEVEL"] = "198"
-  CONFIG["INSTALL"] = '/usr/obj/ports/ruby-2.4.2-no_ri_docs-bootstrap/bin/install -c '
+  CONFIG["TEENY"] = "3"
+  CONFIG["PATCHLEVEL"] = "205"
+  CONFIG["INSTALL"] = '/usr/obj/ports/ruby-2.4.3-no_ri_docs-bootstrap/bin/install -c '
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)24"
@@ -45,7 +45,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--program-suffix=24' '--with-soname=ruby24' '--with-ruby-version=minor' '--with-mantype=doc' '--enable-pthread' '--enable-ipv6' '--without-bundled-libffi' '--disable-option-checking' '--enable-shared' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include' 'CXX=c++' 'CXXFLAGS=-O2 -pipe'"
+  CONFIG["configure_args"] = " '--enable-shared' '--program-suffix=24' '--with-soname=ruby24' '--with-ruby-version=minor' '--with-mantype=doc' '--enable-pthread' '--enable-ipv6' '--without-bundled-libffi' '--disable-option-checking' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include' 'CXX=c++' 'CXXFLAGS=-O2 -pipe'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -94,7 +94,7 @@ module RbConfig
   CONFIG["EXTDLDFLAGS"] = ""
   CONFIG["EXTLDFLAGS"] = ""
   CONFIG["strict_warnflags"] = "-std=gnu99"
-  CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wno-tautological-compare -Wno-parentheses-equality -Wno-constant-logical-operand -Wno-self-assign -Wunused-variable -Wimplicit-int -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wimplicit-function-declaration -Wdeprecated-declarations -Wno-packed-bitfield-compat"
+  CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wno-tautological-compare -Wno-parentheses-equality -Wno-constant-logical-operand -Wno-self-assign -Wunused-variable -Wimplicit-int -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wshorten-64-to-32 -Wimplicit-function-declaration -Wdivision-by-zero -Wdeprecated-declarations -Wextra-tokens"
   CONFIG["debugflags"] = "-ggdb3"
   CONFIG["optflags"] = "-O3 -fno-fast-math"
   CONFIG["NULLCMD"] = ":"
@@ -144,9 +144,9 @@ module RbConfig
   CONFIG["DOT"] = ""
   CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["MKDIR_P"] = "mkdir -p"
-  CONFIG["INSTALL_DATA"] = "/usr/obj/ports/ruby-2.4.2-no_ri_docs-bootstrap/bin/install -c  -m 644"
-  CONFIG["INSTALL_SCRIPT"] = "/usr/obj/ports/ruby-2.4.2-no_ri_docs-bootstrap/bin/install -c  -m 755"
-  CONFIG["INSTALL_PROGRAM"] = "/usr/obj/ports/ruby-2.4.2-no_ri_docs-bootstrap/bin/install -c -s  -m 755"
+  CONFIG["INSTALL_DATA"] = "/usr/obj/ports/ruby-2.4.3-no_ri_docs-bootstrap/bin/install -c  -m 644"
+  CONFIG["INSTALL_SCRIPT"] = "/usr/obj/ports/ruby-2.4.3-no_ri_docs-bootstrap/bin/install -c  -m 755"
+  CONFIG["INSTALL_PROGRAM"] = "/usr/obj/ports/ruby-2.4.3-no_ri_docs-bootstrap/bin/install -c -s  -m 755"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["NM"] = "nm"
@@ -160,7 +160,7 @@ module RbConfig
   CONFIG["AR"] = "ar"
   CONFIG["RANLIB"] = "ranlib"
   CONFIG["try_header"] = ""
-  CONFIG["CC_VERSION_MESSAGE"] = "cc (GCC) 4.2.1 20070719 \nCopyright (C) 2007 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
+  CONFIG["CC_VERSION_MESSAGE"] = "OpenBSD clang version 5.0.1 (tags/RELEASE_501/final) (based on LLVM 5.0.1)\nTarget: armv7-unknown-openbsd6.3-gnueabi\nThread model: posix\nInstalledDir: /usr/bin"
   CONFIG["CC_VERSION"] = "$(CC) --version"
   CONFIG["CSRCFLAG"] = ""
   CONFIG["COUTFLAG"] = "-o "
@@ -183,22 +183,22 @@ module RbConfig
   CONFIG["NACL_SDK_VARIANT"] = ""
   CONFIG["NACL_SDK_ROOT"] = ""
   CONFIG["NACL_TOOLCHAIN"] = ""
-  CONFIG["target_os"] = "openbsd6.2"
+  CONFIG["target_os"] = "openbsd6.3"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "arm"
-  CONFIG["target"] = "arm-unknown-openbsd6.2"
-  CONFIG["host_os"] = "openbsd6.2"
+  CONFIG["target"] = "arm-unknown-openbsd6.3"
+  CONFIG["host_os"] = "openbsd6.3"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "arm"
-  CONFIG["host"] = "arm-unknown-openbsd6.2"
+  CONFIG["host"] = "arm-unknown-openbsd6.3"
   CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
-  CONFIG["build_os"] = "openbsd6.2"
+  CONFIG["build_os"] = "openbsd6.3"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "arm"
-  CONFIG["build"] = "arm-unknown-openbsd6.2"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "2.4.2"
+  CONFIG["build"] = "arm-unknown-openbsd6.3"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "2.4.3"
   CONFIG["cxxflags"] = "$(optflags) $(debugflags) $(warnflags)"
   CONFIG["cppflags"] = ""
   CONFIG["cflags"] = "$(optflags) $(debugflags) $(warnflags)"
